# COPR Ligenix's spec file for glpi-plugin-genericobject
#
# Copyright (c) 2021-2022 Jean-Marc Liger
#
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname genericobject
%global glpi_min   10.0.0
%global glpi_max   10.1.0

Name:           glpi-plugin-%{pluginname}
Version:        2.14.0
Release:        1%{?dist}
Summary:        Plugin to add new inventory types without programmation

License:        GPLv3
URL:            https://github.com/pluginsGLPI/%{pluginname}

Source0:        https://github.com/pluginsGLPI/%{pluginname}/releases/download/%{version}/glpi-%{pluginname}-%{version}.tar.bz2

BuildArch:      noarch

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif


%description
Plugin to add new inventory types without programmation

It manages :
- Type creation
- Available fields
- Framework integration (Helpdesk, loans, templates, etc.)
- Integration with the file injection plugin


%prep
%setup -q -c

grep 'define("PLUGIN_GENERICOBJECT_M.._GLPI' %{pluginname}/setup.php

# remove unused files
rm    %{pluginname}/%{pluginname}.xml
rm    %{pluginname}/composer.json
rm -r %{pluginname}/vendor

# move doc files
mv %{pluginname}/docs              docs
mv %{pluginname}/AUTHORS.txt       docs/
mv %{pluginname}/README.md         docs/
mv %{pluginname}/%{pluginname}.gif docs/
mv %{pluginname}/glpi_network.png  docs/

# Create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# empty build


%install
mkdir -p %{buildroot}%{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}

mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc docs/*
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/%{pluginname}.png
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/ajax
%{_datadir}/glpi/plugins/%{pluginname}/css
%{_datadir}/glpi/plugins/%{pluginname}/fields
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/objects
%{_datadir}/glpi/plugins/%{pluginname}/pics
# data
%attr(750,apache,root) %{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}


%changelog
* Thu Sep 29 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.14.0-1
- Version 2.14.0

* Sat Jul 30 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.12.1-1
- Version 2.12.1 for GLPI 10.0.x

* Mon Apr 04 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.11.1-1
- Version 2.11.1

* Fri May 28 2021 Jean-Marc Liger <ligenix@iscp.fr> - 2.11.0-1
- Version 2.11.0

* Mon May 17 2021 Jean-Marc Liger <ligenix@iscp.fr> - 2.10.1-1
- Initial RPM based on Remi Collet previous GLPI plugins spec files
